@@ -1,6 +1,7 @@
 # @describe A demo cli
 
 # @cmd Upload a file
+# @alias    u
 # @arg target!                      File to upload
 upload() {
     echo "cmd                       upload"
@@ -8,10 +9,11 @@ upload() {
 }
 
 # @cmd Download a file
-# @flag     -f --force              Override existed file
-# @option   -t --tries <NUMBER>     Set number of retries to NUMBER
+# @alias    d
+# @flag     -f --force              Override existing file
+# @option   -t --tries <NUM>        Set number of retries to NUM
 # @arg      source!                 Url to download from
-# @arg      target                  Svae file to
+# @arg      target                  Save file to
 download() {
     echo "cmd:                      download"
     echo "flag:   --force           $argc_force"
@@ -20,4 +22,4 @@ download() {
     echo "arg:    target            $argc_target"
 }
 
-eval "$(argc -e $0 "$@")"
\ No newline at end of file
+eval "$(argc $0 "$@")"
